.. _single_table_models:

Models
======
In this section, you'll find information about using synthetic data models for single table data.

.. note::
   Is this your first time using the SDV?

   We recommend starting with the new, :ref:`tabular_preset` model. This model comes pre-configured
   so you can spend less time choosing parameters or tuning a model, and more time using your
   synthetic data.


.. toctree::
    :maxdepth: 2

    tabular_preset
    gaussian_copula
    ctgan
    copulagan
    tvae
